@@ -21,6 +21,25 @@ FGCOLOR_LIGHT_MAGENTA = "\x1b[95m"
 FGCOLOR_LIGHT_CYAN = "\x1b[96m"
 FGCOLOR_WHITE = "\x1b[97m"
 
+ALL_FGCOLORS = [
+	FGCOLOR_BLACK,
+	FGCOLOR_RED,
+	FGCOLOR_GREEN,
+	FGCOLOR_YELLOW,
+	FGCOLOR_BLUE,
+	FGCOLOR_MAGENTA,
+	FGCOLOR_CYAN,
+	FGCOLOR_LIGHT_GRAY,
+	FGCOLOR_DARK_GRAY,
+	FGCOLOR_LIGHT_RED,
+	FGCOLOR_LIGHT_GREEN,
+	FGCOLOR_LIGHT_YELLOW,
+	FGCOLOR_LIGHT_BLUE,
+	FGCOLOR_LIGHT_MAGENTA,
+	FGCOLOR_LIGHT_CYAN,
+	FGCOLOR_WHITE,
+]
+
 BGCOLOR_BLACK = "\x1b[40m"
 BGCOLOR_RED = "\x1b[41m"
 BGCOLOR_GREEN = "\x1b[42m"
@@ -39,6 +58,25 @@ BGCOLOR_LIGHT_MAGENTA = "\x1b[105m"
 BGCOLOR_LIGHT_CYAN = "\x1b[106m"
 BGCOLOR_WHITE = "\x1b[107m"
 
+ALL_BGCOLORS = [
+	BGCOLOR_BLACK,
+	BGCOLOR_RED,
+	BGCOLOR_GREEN,
+	BGCOLOR_YELLOW,
+	BGCOLOR_BLUE,
+	BGCOLOR_MAGENTA,
+	BGCOLOR_CYAN,
+	BGCOLOR_LIGHT_GRAY,
+	BGCOLOR_DARK_GRAY,
+	BGCOLOR_LIGHT_RED,
+	BGCOLOR_LIGHT_GREEN,
+	BGCOLOR_LIGHT_YELLOW,
+	BGCOLOR_LIGHT_BLUE,
+	BGCOLOR_LIGHT_MAGENTA,
+	BGCOLOR_LIGHT_CYAN,
+	BGCOLOR_WHITE,
+]
+
 STYLE_RESET = "\x1b[0m"
 
 
